const checkDebug = require('debug')('graphed:check')
const refreshDebug = require('debug')('graphed:refresh')
const config = require('./config')
const path = require('path')
const normapi = require('normapi');
const request = require('request')

let api = new normapi()

const check = object => {
  return new Promise((resolve, reject) => {
    const url = path.join(config.checkIfLoggedInURL, object.appId)
    request.post({
      headers: {
        'content-type': 'application/json'
      },
      url: url,
      form: {
        uniquekey: object.loggedUser,
        fingerprint: object.fingerprint,
        lalo: object.location
      }
    }, function(err, res, body) {
      checkDebug(err, body)
      if(err) reject({
        type:'request-error', 
        func: '@check', 
        lCode: '-E1',
        msg: 'Hiba a szerver csatlakozás közben!'
      })
      else {
        try {
          body = JSON.parse(body)
          resolve({
            func: '@graphedCheckLogin-CHECK', 
            lCode: '-S1', 
            msg:'Sikeres ellenőrzés',
            document: body
          })
        }
        catch(e) {reject(e)}
      }
    })
  })
}

const refresh = object => {
  return new Promise((resolve, reject) => {
    const url = config.refreshUrl
    request.post({
      headers: {
        'content-type': 'application/json'
      },
      url: url,
      form: {
        uniquekey: object.loggedUser,
        lalo: object.location
      }
    }, function(err, res, body) {
      refreshDebug(err, body)
      if(err) reject({
        type:'request-error', 
        func: '@refresh', 
        lCode: '-E1',
        msg: 'Hiba a szerver csatlakozás közben!'
      })
      try {
        body = JSON.parse(body)
        resolve({
          func: '@refresh',
          lCode: '-S1',
          document: body
        })
      }
      catch(e) {reject(e)}
    })
  })
}

api.addFunction({name: 'check'}, check)
api.addFunction({name: 'refresh'}, refresh)

module.exports = api